<<<<<<< HEAD
## Get Real Flights [![Build Status](https://travis-ci.com/pikachu1992/get_real_flights.svg?branch=master)](https://travis-ci.com/pikachu1992/get_real_flights)
=======
## Get Real Flights [![Build Status](https://travis-ci.com/pikachu1992/get-real-flights.svg?branch=master)](https://travis-ci.com/pikachu1992/get-real-flights)
>>>>>>> master

Generates a random real flights from FlightRadar24 data..

## Installation
> `pip install get-real-flights`

## Usage
> `Run run.py to genenate json file with real flights from present day.`

## Options:


## Usage Examples
> `python3 run.py`
